# CHANGELOG
## 1.1.0 (2015-08-14)
- Refactor code
- Added new functions: send_queue, send_thread, send_blocking, add_subscribe

## 1.0.2 (2015-08-14)
- increase performance function send (19%+)
- increase performance subscribe (2%+)

## 1.0.1 (2015-08-13)
- fix pip install basicevents

## 1.0.0 (2015-08-13)
- Now you can run blocker way events
- break compatibility function send (check documentation)

## 0.1.5 (2015-08-12)
- update documentation

## 0.1.4 (2015-08-12)
- update documentation
- remove instant key in kwargs

## 0.1.3 (2015-08-12)
- Added changelog
- Auto convert md to rst in setup.py
